@@ -3,12 +3,13 @@ use proc_macro::{Delimiter, Group, Ident, Span, TokenStream, TokenTree};
 #[proc_macro_attribute]
 pub fn public(args: TokenStream, input: TokenStream) -> TokenStream {
     let mut pub_token = TokenStream::from(TokenTree::Ident(Ident::new("pub", Span::call_site())));
-    if args.clone().is_empty() {
-        let crate_token = TokenStream::from(TokenTree::Ident(Ident::new("crate", Span::call_site())));
+    if args.is_empty() {
+        let crate_token =
+            TokenStream::from(TokenTree::Ident(Ident::new("crate", Span::call_site())));
         let scope_group = Group::new(Delimiter::Parenthesis, crate_token);
         pub_token.extend(TokenStream::from(TokenTree::Group(scope_group)));
     } else {
-        let scope_group = Group::new(Delimiter::Parenthesis, args);
+        let scope_group = Group::new(Delimiter::Parenthesis, args.clone());
         pub_token.extend(TokenStream::from(TokenTree::Group(scope_group)));
     }
 
